@@ -13,7 +13,7 @@
 #' Before jumping into the details it is useful to have an understanding of the
 #' differences between MARK (via the \code{mark in RMark} function) and the
 #' package \code{mra} written by Trent McDonald and how they relate to the
-#' implementation in \code{\link{cjs}}.  With MARK, animals can be placed in
+#' implementation in \code{\link{cjs_admb}}.  With MARK, animals can be placed in
 #' groups and the parameters for the model specified via PIMs (parameter
 #' index matrices) link the parameters to the specific animals.  For
 #' example, if for a particular group the \code{Phi} PIM is
@@ -65,7 +65,7 @@
 #' using the R facilities for handling factor variables in the formula to
 #' create the design matrix.
 #' 
-#' In the \code{crm,cjs,js} functions in this package I have used basic idea in
+#' In the \code{crm,cjs_admb,js} functions in this package I have used basic idea in
 #' \code{mra} but I have taken a different approach to model development that
 #' allows for time-varying covariates but does not restrict each covariate to
 #' be time-varying and factor variables are used as such which removes the need
@@ -266,6 +266,11 @@ create.dmdf=function(x,parameter,time.varying=NULL,fields=NULL)
 	   df=merge(df,timedf,by="occid")
 	   df$idocc=NULL
    }
+   if(any(time.intervals==0))
+   {
+	   firstocc=data.frame(id=factor(1:nrow(x$data)),firstocc=firstseen)
+	   df=merge(df,firstocc,by="id")
+   }
    df=df[order(df$seq),]
    df$age=df$time-df$cohort
    if(!is.null(x$data$initial.age)) df$age=df$age+x$data$initial.age[df$id]
