@@ -2,7 +2,7 @@
 #' 
 #' Computes 1 to k-step forward transition proportions in each state with a single transition matrix or a 3-d array of transition matrices.
 #' 
-#' @param x either a transition matrix or 3-d array ( a set of transition matrices)
+#' @param x either a transition matrix, list of transition matrices or 3-d array ( a set of transition matrices)
 #' @param k if x is a transition matrix, this is number of steps 1 to k
 #' @param labels labels for states except for last which is always dead and is added at end
 #' @author Jeff Laake
@@ -11,6 +11,13 @@
 #' @keywords utility
 omega=function(x,k=NULL,labels=NULL)
 {
+	if(is.list(x))
+	{
+		y=x
+		x=array(NA,dim=c(length(y),nrow(y[[1]]),ncol(y[[1]])))
+		for(i in 1:length(y))
+			x[i,,]=y[[i]]
+	}	
 	array_dim=dim(x)
 	if(length(array_dim)==2)
 	{
@@ -28,7 +35,7 @@ omega=function(x,k=NULL,labels=NULL)
 		  mat[j,]=xmat[1,]
 		}
 	}
-	colnames(mat)=c(labels,"Dead")
+	if(!is.null(labels))colnames(mat)=c(labels,"Dead")
 	rownames(mat)=1:k
 	return(mat)
 }
